@@ -4,12 +4,20 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_13';
+  our $VERSION = '0.18_01';
 
   use Zydeco
     authority => 'cpan:SMONFF',
-    # Predeclaration of types avoid use of quotes https://gitlab.com/smonff/art-world/-/issues/37
-    declare => [ 'Agent', 'Artwork', 'Collector', 'Idea', 'Theory' ],
+    # Predeclaration of types avoid use of quotes in args types declarations or
+    # signatures. See https://codeberg.org/smonff/art-world/issues/37
+    declare => [
+      'Agent',
+      'Artwork',
+      'Collector',
+      'Idea',
+      'Place',
+      'Theory',
+     ],
     version   => $VERSION;
 
   use feature qw( postderef );
@@ -19,7 +27,7 @@ package Art::World {
   use Config::Tiny;
   use DDP;
   use Faker;
-  use List::Util qw( max );
+  use List::Util qw( max any );
   use Math::Round;
 
   role Abstraction {
@@ -40,7 +48,6 @@ package Art::World {
     }
   }
 
-
   role Active {
     method participate {
       say "That's interesting";
@@ -122,8 +129,13 @@ package Art::World {
   }
 
   role Manager {
+    has places ( type => ArrayRef[ Place ] );
 
     method organize {}
+
+    method influence ( Int $reputation) {
+      return $self->config->{ FAME }->{ MANAGER_BUMP } * $reputation;
+    }
   }
 
   role Market {
@@ -163,9 +175,7 @@ package Art::World {
     # TODO an implemented project (Work, Exhibition) should inherit of this
     # TODO some stuff should extends this
     abstract class Concept {
-      class Idea  with Abstraction {
-
-      }
+      class Idea  with Abstraction { }
       class Theory  with Abstraction { }
     }
 
@@ -226,13 +236,26 @@ package Art::World {
       # TODO In case the networker is a Manager, the reputation bump
       # should be higher
       method networking( ArrayRef $people ) {
-        my $highest_reputation = max map { $_-> reputation } @$people;
+        my $highest_reputation = max map { $_-> reputation } $people->@*;
         my $bump = $highest_reputation > 1 ?
-            round( $highest_reputation * 10 / 100) :
-            $self->config->{ FAME }->{ DEFAULT_BUMP };
-        for my $agent ( @$people ) {
+          round( $highest_reputation * $self->config->{ FAME }->{ BUMP_COEFFICIENT } / 100) :
+          $self->config->{ FAME }->{ DEFAULT_BUMP };
+        for my $agent ( $people->@* ) {
           $agent->bump_fame( $bump );
         }
+
+        if ( any { $_->does( 'Art::World::Manager' ) } $people->@* ) {
+          my @managers = grep { $_->does( 'Art::World::Manager' )} $people->@*;
+          my $highest_influence_manager    =  max map { $self } @managers;
+          # Bump all the other persons with the Manager->influence thing
+          # but not the Manager with the highest influence otherwise it would
+          # increase it's own reputation
+          my @all_the_other = grep { $_->id != $highest_influence_manager->id } $people->@*;
+          for my $agent ( @all_the_other ) {
+            # The influence() methode is only a way of bumping_fame() with a special bumper
+            $agent->bump_fame( $highest_influence_manager->influence( $agent->reputation ));
+          }
+        }
       }
 
       class Artist {
@@ -288,7 +311,7 @@ package Art::World {
         method write( Theory $catalog ) { }
       }
 
-      class Director with Manager {    }
+      class Director with Manager { }
 
       class Public {
         method visit {
@@ -301,7 +324,7 @@ package Art::World {
     }
 
 
-    class Work with Fame {
+    class Work extends Concept with Fame {
 
       has creation_date;
       has creator(
@@ -316,7 +339,7 @@ package Art::World {
       # Same as Agent->reputation
       has aura( is => rw, type => PositiveOrZeroNum );
 
-      class Article;
+      class Article
 
       class Artwork with Showable, Collectionable  {
         has material;
@@ -330,7 +353,7 @@ package Art::World {
       class Exhibition with Event {
         has curator! (
           is   => ro,
-          type => ArrayRef[ Agent ] );
+          type => ArrayRef[ Curator ] );
       }
     }
 
@@ -372,7 +395,7 @@ __END__
 
 =head1 NAME
 
-Art::World - Agents interactions modeling  🎨
+Art::World - Agents interactions modeling
 
 =head1 SYNOPSIS
 
@@ -470,7 +493,8 @@ I guess.
 =head2 Manager
 
 A role for those who I<take care> of exhibitions and other organizational
-matters.
+matters. See how being a C<Manager> influence an C<Agent> in the L<CLASSES>
+section.
 
 =head2 Showable
 
@@ -492,10 +516,24 @@ kind of C<Agent> classes and roles.
 
 The C<Agent> got an a C<networking( $people )> method. When it is passed and
 C<ArrayRef> of various implementation classes of C<Agents> (C<Artist>,
-C<Curator>, etc.) it bumps the C<reputation> atributes of all of 1/10 of the
+C<Curator>, etc.) it bumps the C<reputation> attributes of all of 1/10 of the
 C<Agent> with the highest reputation. If this reputation is less than 1, it is
 rounded to the C<$self->config->{ FAME }->{ DEFAULT_BUMP }> constant.
 
+The bump coefficient can be adjusted in the configuration through C<{ FAME }->{
+BUMP_COEFFICIENT }>.
+
+There is also a special way of bumping fame when C<Manager>s are in a Networking
+activity: The C<influence()> method makes possible to apply the special
+C<$self->config->{ FAME }->{ MANAGER_BUMP }> constant. Then the C<Agent>s
+reputations are bumped by the C<MANAGER_BUMP> value multiplicated by the highest
+networking C<Manager> reputation. This is what the C<influence()> method
+returns:
+
+  return $self->config->{ FAME }->{ MANAGER_BUMP } * $reputation;
+
+The default values can be edited in C<art.conf>.
+
 =head2 Art
 
 Will be what you decide it to be depending on how you combine all the entities.
@@ -506,19 +544,27 @@ Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.
 
 =head2 Artist
 
+In the beginning of their carreer they are usually underground and produce
+experimental art, but this can change in time.
+
+  $artist->is_underground if not $artist->has_collectors;
+
+After getting collected, artists become homogenic.
+
 The artist got a lots of wonderful powers:
 
 =over
 
 =item C<create>
 
+When the basic abstractions of Art are articulated, a creation occurs. It
+doesn't mean that it will create an C<Artwork>, because it requires the
+intervention of other C<Agents>. The C<Artist> creates through a work concept.
+This articulation can group the different attributes of the C<Abstraction> role:
+C<discourse>, C<file>, C<idea>, C<process>, C<project> and C<time>.
+
 =item C<have_idea> all day long
 
-In the beginning of their carreer they are usually underground, but this can
-change in time.
-
-  $artist->is_underground if not $artist->has_collectors;
-
 =back
 
 =head2 Artwork
@@ -648,8 +694,12 @@ Toby Inkster
 
 =back
 
+=head1 ACKNOWLEDGMENT
+
+This project was made possible by the greatness of L<Zydeco|https://zydeco.toby.ink/>.
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2020 Sebastien Feugère
+Copyright 2006-2021 Sebastien Feugère
 
 This library is free software; you can redistribute it and/or modify it under the Artistic License 2.0.
